summaryrefslogtreecommitdiffstats
path: root/kdejava/koala/test/kbase
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-02-01 15:12:07 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-02-01 15:12:07 -0600
commit3ed7c09d22a5f310a97516f5bab6068e5688a813 (patch)
tree23ba07d28f7fad17824db1fc40e9cf1ad4942480 /kdejava/koala/test/kbase
parent3a8473ba2620b85b165b5a2fa1a6b153f5945800 (diff)
downloadtdebindings-3ed7c09d22a5f310a97516f5bab6068e5688a813.tar.gz
tdebindings-3ed7c09d22a5f310a97516f5bab6068e5688a813.zip
Rename a number of classes to enhance compatibility with KDE4
Diffstat (limited to 'kdejava/koala/test/kbase')
-rw-r--r--kdejava/koala/test/kbase/KBase.java50
-rw-r--r--kdejava/koala/test/kbase/KBaseDoc.java2
2 files changed, 26 insertions, 26 deletions
diff --git a/kdejava/koala/test/kbase/KBaseDoc.java b/kdejava/koala/test/kbase/KBaseDoc.java
index d253123b..8c42c40d 100644
--- a/kdejava/koala/test/kbase/KBaseDoc.java
+++ b/kdejava/koala/test/kbase/KBaseDoc.java
@@ -6,7 +6,7 @@ import org.kde.koala.*;
/** KBaseDoc provides a document object for a document-view model.
*
* The KBaseDoc class provides a document object that can be used in conjunction with the classes JavaApiTestApp and KBaseView
- * to create a document-view model for standard KDE applications based on TDEApplication and KMainWindow. Thereby, the document object
+ * to create a document-view model for standard KDE applications based on TDEApplication and TDEMainWindow. Thereby, the document object
* is created by the JavaApiTestApp instance and contains the document structure with the according methods for manipulation of the document
* data by KBaseView objects. Also, KBaseDoc contains the methods for serialization of the document data from and to files.
*
diff --git a/kdejava/koala/test/kbase/KBase.java b/kdejava/koala/test/kbase/KBase.java
index 0e0117de..1be572bd 100644
--- a/kdejava/koala/test/kbase/KBase.java
+++ b/kdejava/koala/test/kbase/KBase.java
@@ -8,16 +8,16 @@ import org.kde.koala.*;
* window and reads the config file as well as providing a menubar, toolbar
* and statusbar. An instance of KBaseView creates your center view, which is connected
* to the window's Doc object.
* KBase reimplements the methods that KMainWindow provides for main window handling and supports
* full session management as well as using KActions.
* @see KMainWindow
* @see TDEApplication
* @see TDEConfig
*
* @author Source Framework Automatically Generated by KDevelop, (c) The KDevelop Team.
* @version KDevelop version 1.2 code generation
*/
-public class KBase extends KMainWindow
+public class KBase extends TDEMainWindow
{
public static final int ID_STATUS_MSG = 1;
@@ -34,21 +34,21 @@ public class KBase extends KMainWindow
*/
private KBaseDoc doc;
- // KAction references to enable/disable actions
- private KAction fileNewWindow;
- private KAction fileNew;
- private KAction fileOpen;
- private KRecentFilesAction fileOpenRecent;
- private KAction fileSave;
- private KAction fileSaveAs;
- private KAction fileClose;
- private KAction filePrint;
- private KAction fileQuit;
- private KAction editCut;
- private KAction editCopy;
- private KAction editPaste;
- private KToggleAction viewToolBar;
- private KToggleAction viewStatusBar;
+ // TDEAction references to enable/disable actions
+ private TDEAction fileNewWindow;
+ private TDEAction fileNew;
+ private TDEAction fileOpen;
+ private TDERecentFilesAction fileOpenRecent;
+ private TDEAction fileSave;
+ private TDEAction fileSaveAs;
+ private TDEAction fileClose;
+ private TDEAction filePrint;
+ private TDEAction fileQuit;
+ private TDEAction editCut;
+ private TDEAction editCopy;
+ private TDEAction editPaste;
+ private TDEToggleAction viewToolBar;
+ private TDEToggleAction viewStatusBar;
/** construtor of KBase, calls all init functions to create the application.
*/
@@ -81,13 +81,13 @@ public KBase()
this(null, null);
}
- /** initializes the KActions of the application */
+ /** initializes the TDEActions of the application */
protected void initActions()
{
- fileNewWindow = new KAction(tr("New &Window"), "", new KShortcut(), this, SLOT("slotFileNewWindow()"), actionCollection(),"file_new_window");
+ fileNewWindow = new TDEAction(tr("New &Window"), "", new TDEShortcut(), this, SLOT("slotFileNewWindow()"), actionCollection(),"file_new_window");
fileNew = KStdAction.openNew(this, SLOT("slotFileNew()"), actionCollection());
fileOpen = KStdAction.open(this, SLOT("slotFileOpen()"), actionCollection());
- fileOpenRecent = (KRecentFilesAction) KStdAction.openRecent(this, SLOT("slotFileOpenRecent(KURL)"), actionCollection());
+ fileOpenRecent = (TDERecentFilesAction) KStdAction.openRecent(this, SLOT("slotFileOpenRecent(KURL)"), actionCollection());
fileSave = KStdAction.save(this, SLOT("slotFileSave()"), actionCollection());
fileSaveAs = KStdAction.saveAs(this, SLOT("slotFileSaveAs()"), actionCollection());
// this one crashes for me...
@@ -216,7 +216,7 @@ protected void readOptions()
// bar position settings
// int toolBarPos;
- //Pos=(int) config.readNumEntry("ToolBarPos", KToolBar.Top);
+ //Pos=(int) config.readNumEntry("ToolBarPos", TDEToolBar.Top);
// toolBar("mainToolBar").setBarPos(toolBarPos);
// initialize the recent file list
@@ -446,11 +446,11 @@ public void slotFileQuit()
saveOptions();
// close the first window, the list makes the next one the first again.
// This ensures that queryClose() is called on each window to ask for closing
- KMainWindow w;
+ TDEMainWindow w;
Iterator it = memberList().iterator();
while(it.hasNext())
{
- w=(KMainWindow)it.next();
+ w=(TDEMainWindow)it.next();
// only close the window if the closeEvent is accepted. If the user presses Cancel on the saveModified() dialog,
// the window and the application stay open.
if(!w.close())
@@ -8,16 +8,16 @@ import org.kde.koala.*;
* and statusbar. An instance of KBaseView creates your center view, which is connected
* to the window's Doc object.
- * KBase reimplements the methods that KMainWindow provides for main window handling and supports
- * full session management as well as using KActions.
- * @see KMainWindow
+ * KBase reimplements the methods that TDEMainWindow provides for main window handling and supports
+ * full session management as well as using TDEActions.
+ * @see TDEMainWindow
* @see TDEApplication
* @see TDEConfig